@@ -3,7 +3,6 @@
 #' Automating the creation of Stan code for a TDCM.
 #'
 #' @param q_matrix A tibble containing the assessment Q-matrix.
-#' @param profs A tibble of the possible attribute mastery profiles.
 #'
 #' @return `stan_code` A list containing the text for the Stan code blocks.
 #'
@@ -11,9 +10,10 @@
 #'
 #' @examples
 #' qmatrix = tibble::tibble(att_1 = c(1, 0, 1, 0, 1, 1), att_2 = c(0, 1, 0, 1, 1, 1))
-#' possible_profiles = tibble::tibble(att_1 = c(0, 1, 0, 1), att_2 = c(0, 1, 0, 1))
-#' create_stan_tdcm(q_matrix = qmatrix, profs = possible_profiles)
-create_stan_tdcm <- function(q_matrix, profs) {
+#' create_stan_tdcm(q_matrix = qmatrix)
+create_stan_tdcm <- function(q_matrix) {
+  profs <- bin_profile(ncol(q_matrix))
+
   colnames(q_matrix) <- glue::glue("att_{1:ncol(q_matrix)}")
 
   int0 <- glue::glue("real l{1:nrow(q_matrix)}_0;")
@@ -225,7 +225,6 @@ create_stan_tdcm <- function(q_matrix, profs) {
                "  int<lower=1> C;                    // number of classes",
                "  int<lower=1> A;                    // number of attributes",
                "  int<lower=1,upper=I> ii[N, 2];     // item for obs n",
-               "  int<lower=1,upper=J> jj[N, 2];     // respondent for obs n",
                "  int<lower=0,upper=1> y[N, 2];      // score for obs n",
                "  int<lower=1,upper=N> s[J, 2];      // starting row for j",
                "  int<lower=1,upper=I> l[J, 2];      // number of items for j",
