@@ -3,7 +3,6 @@
 #' Automating the creation of multi-threaded Stan code for a TDCM.
 #'
 #' @param q_matrix A tibble containing the assessment Q-matrix.
-#' @param profs A tibble of the possible attribute mastery profiles.
 #'
 #' @return `stan_code` A list containing the text for the Stan code blocks.
 #'
@@ -11,9 +10,10 @@
 #'
 #' @examples
 #' qmatrix = tibble::tibble(att_1 = c(1, 0, 1, 0, 1, 1), att_2 = c(0, 1, 0, 1, 1, 1))
-#' possible_profiles = tibble::tibble(att_1 = c(0, 1, 0, 1), att_2 = c(0, 1, 0, 1))
-#' create_threaded_stan_tdcm(q_matrix = qmatrix, profs = possible_profiles)
-create_threaded_stan_tdcm <- function(q_matrix, profs) {
+#' create_threaded_stan_tdcm(q_matrix = qmatrix)
+create_threaded_stan_tdcm <- function(q_matrix) {
+  profs <- bin_profile(ncol(q_matrix))
+
   colnames(q_matrix) <- glue::glue("att_{1:ncol(q_matrix)}")
 
   int0 <- glue::glue("real l{1:nrow(q_matrix)}_0;")
